@@ -165,7 +165,7 @@ var InlineSpellCheckerUI = {
 
     for (var i = 0; i < list.length; i ++) {
       // get the display name for this dictionary
-      isoStrArray = list[i].split("-");
+      isoStrArray = list[i].split(/[-_]/);
       var displayName = "";
       if (this.mLanguageBundle && isoStrArray[0]) {
         try {
@@ -186,6 +186,7 @@ var InlineSpellCheckerUI = {
 
       this.mDictionaryNames.push(list[i]);
       var item = document.createElement("menuitem");
+      item.setAttribute("id", "spell-check-dictionary-" + list[i]);
       item.setAttribute("label", displayName);
       item.setAttribute("type", "checkbox");
       this.mDictionaryItems.push(item);
